osirispy module
================

Module methods
**************

.. autofunction:: osirispy.read


Module classes
**************
.. autoclass:: osirispy.os_data
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: osirispy.grid
    :members:
    :special-members: __init__
    :show-inheritance:

.. autoclass:: osirispy.axis
    :members:
    :special-members: __init__
    :show-inheritance:


.. autoclass:: osirispy.raw
    :members:
    :special-members: __init__
    :show-inheritance:


.. autoclass:: osirispy.track
    :members:
    :special-members: __init__
    :show-inheritance:
